# semi_pyramid_generator
The *semi_pyramid_generator* package allows you to generate semi-pyramids by just using 2 functions which are `make_normal_semi_pyramid(<enter pyramid length>)` which is a normal semi-pyramid and `make_reversed_semi_pyramid(<enter pyramid length>)` which is a reversed semi-pyramid
> *     End of long description         